@@ -7,7 +7,12 @@ from petisco.base.misc.interface import Interface
 
 class MessageConfigurer(Interface):
     @abstractmethod
-    def configure_subscribers(self, subscribers: List[MessageSubscriber]):
+    def configure_subscribers(
+        self,
+        subscribers: List[MessageSubscriber],
+        clear_subscriber_before: bool = False,
+        clear_store_before: bool = False,
+    ):
         raise NotImplementedError
 
     @abstractmethod
