@@ -13,5 +13,15 @@ class NotImplementedDomainEventBus(DomainEventBus):
         meta = self.get_configured_meta()
         _ = domain_event.update_meta(meta)
 
+    def retry_publish(
+        self,
+        domain_event: DomainEvent,
+        retry_routing_key: str,
+        retry_exchange_name: str = None,
+    ):
+        self._check_is_domain_event(domain_event)
+        meta = self.get_configured_meta()
+        _ = domain_event.update_meta(meta)
+
     def close(self):
         pass
