@@ -5,7 +5,12 @@ from petisco.base.domain.message.message_subscriber import MessageSubscriber
 
 
 class NotImplementedMessageConfigurer(MessageConfigurer):
-    def configure_subscribers(self, subscribers: List[MessageSubscriber]):
+    def configure_subscribers(
+        self,
+        subscribers: List[MessageSubscriber],
+        clear_subscriber_before: bool = False,
+        clear_store_before: bool = False,
+    ):
         pass
 
     def clear(self):
